package com.sooka.system.service;

import java.util.List;
import com.sooka.system.domain.TgjjGrzhxx;

/**
 * 个人账户信息Service接口
 * 
 * @author lei
 * @date 2021-11-16
 */
public interface ITgjjGrzhxxService 
{
    /**
     * 查询个人账户信息
     * 
     * @param ID 个人账户信息ID
     * @return 个人账户信息
     */
    public TgjjGrzhxx selectTgjjGrzhxxById(Long ID);

    /**
     * 查询个人账户信息列表
     * 
     * @param tgjjGrzhxx 个人账户信息
     * @return 个人账户信息集合
     */
    public List<TgjjGrzhxx> selectTgjjGrzhxxList(TgjjGrzhxx tgjjGrzhxx);

    /**
     * 新增个人账户信息
     * 
     * @param tgjjGrzhxx 个人账户信息
     * @return 结果
     */
    public int insertTgjjGrzhxx(TgjjGrzhxx tgjjGrzhxx);

    /**
     * 修改个人账户信息
     * 
     * @param tgjjGrzhxx 个人账户信息
     * @return 结果
     */
    public int updateTgjjGrzhxx(TgjjGrzhxx tgjjGrzhxx);

    /**
     * 批量删除个人账户信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTgjjGrzhxxByIds(String ids);

    /**
     * 删除个人账户信息信息
     * 
     * @param ID 个人账户信息ID
     * @return 结果
     */
    public int deleteTgjjGrzhxxById(Long ID);
}
