package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjGrzhxx;
import com.sooka.system.service.ITgjjGrzhxxService;

/**
 * 个人账户信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/grzhxx")
public class TgjjGrzhxxController extends BaseController
{
    private String prefix = "system/grzhxx";

    @Autowired
    private ITgjjGrzhxxService tgjjGrzhxxService;

    @RequiresPermissions("system:grzhxx:view")
    @GetMapping()
    public String grzhxx()
    {
        return prefix + "/grzhxx";
    }

    /**
     * 查询个人账户信息列表
     */
    @RequiresPermissions("system:grzhxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjGrzhxx tgjjGrzhxx)
    {
        startPage();
        List<TgjjGrzhxx> list = tgjjGrzhxxService.selectTgjjGrzhxxList(tgjjGrzhxx);
        return getDataTable(list);
    }

    /**
     * 导出个人账户信息列表
     */
    @RequiresPermissions("system:grzhxx:export")
    @Log(title = "个人账户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjGrzhxx tgjjGrzhxx)
    {
        List<TgjjGrzhxx> list = tgjjGrzhxxService.selectTgjjGrzhxxList(tgjjGrzhxx);
        ExcelUtil<TgjjGrzhxx> util = new ExcelUtil<TgjjGrzhxx>(TgjjGrzhxx.class);
        return util.exportExcel(list, "grzhxx");
    }

    /**
     * 新增个人账户信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存个人账户信息
     */
    @RequiresPermissions("system:grzhxx:add")
    @Log(title = "个人账户信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjGrzhxx tgjjGrzhxx)
    {
        return toAjax(tgjjGrzhxxService.insertTgjjGrzhxx(tgjjGrzhxx));
    }

    /**
     * 修改个人账户信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjGrzhxx tgjjGrzhxx = tgjjGrzhxxService.selectTgjjGrzhxxById(ID);
        mmap.put("tgjjGrzhxx", tgjjGrzhxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存个人账户信息
     */
    @RequiresPermissions("system:grzhxx:edit")
    @Log(title = "个人账户信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjGrzhxx tgjjGrzhxx)
    {
        return toAjax(tgjjGrzhxxService.updateTgjjGrzhxx(tgjjGrzhxx));
    }

    /**
     * 删除个人账户信息
     */
    @RequiresPermissions("system:grzhxx:remove")
    @Log(title = "个人账户信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjGrzhxxService.deleteTgjjGrzhxxByIds(ids));
    }
}
